/***************************************************************************
 *                                  _   _ ____  _
 *  Project                     ___| | | |  _ \| |
 *                             / __| | | | |_) | |
 *                            | (__| |_| |  _ <| |___
 *                             \___|\___/|_| \_\_____|
 *
 * Copyright (C) 2014 - 2016, Steve Holme, <steve_holme@hotmail.com>.
 *
 * This software is licensed as described in the file COPYING, which
 * you should have received as part of this distribution. The terms
 * are also available at https://curl.haxx.se/docs/copyright.html.
 *
 * You may opt to use, copy, modify, merge, publish, distribute and/or sell
 * copies of the Software, and permit persons to whom the Software is
 * furnished to do so, under the terms of the COPYING file.
 *
 * This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY
 * KIND, either express or implied.
 *
 ***************************************************************************/

/**
 * @file	curl_extensions.h
 * @brief	API for privacy-guard-dlp
 */

#ifdef USE_TIZEN_FEATURE_DLP
#ifndef HEADER_CURL_EXTENSIONS_H
#define HEADER_CURL_EXTENSIONS_H

#include <stddef.h>

/**
 * @fn void curl_extensions_tizen_dlp_init(void)
 * @brief Initialize the DLP creating the Load Rules and Logging threads
 * @callgraph
 */
void curl_extensions_tizen_dlp_init(void);

/**
 * @fn void curl_extensions_tizen_dlp_check_leak(const char *hostname, char * const mem, size_t len)
 * @brief Checks for information leak on a given request string
 *
 * @param[in] hostname					The hostname of the server to which the request will be sent
 * @param[in] mem						Text that we are going to validate for info leak
 * @param[in] len						Size of len in bytes
 *
 * @return  either PRIV_GUARD_DLP_RESULT_ALLOW or PRIV_GUARD_DLP_RESULT_DENY
 * @callgraph
 */
void curl_extensions_tizen_dlp_check_leak(const char *hostname, char * const mem, size_t len);

#endif /* HEADER_CURL_EXTENSIONS_H */
#endif /* USE_TIZEN_FEATURE_DLP */
